@@ -76,6 +76,8 @@ class Models:
             Column("time_s", Integer, nullable=False),
             Column("author_public_key", LargeBinary(
                 33), index=True, nullable=False),
+            Column("recipient_public_key", LargeBinary(
+                33), index=True, nullable=True),
             Column("secret_key", LargeBinary(32), nullable=True),
             Column("block_time_s", Integer, nullable=False),
             Column("liked_time_ms", SLBigInteger, default=None, nullable=True),
@@ -193,7 +195,6 @@ class Models:
             "config",
             self.metadata,
             Column("username", String, primary_key=True),
-            Column("twitter_bearer_token", String, nullable=True),
             Column("sell_price_msat", Integer, nullable=True),
         )
 
@@ -203,4 +204,5 @@ class Models:
             Column("twitter_account_id", Integer, primary_key=True),
             Column("handle", String, unique=True, nullable=False),
             Column("profile_id", Integer, nullable=False),
+            Column("bearer_token", String, nullable=False),
         )
